#########
/database
#########

This is where all functions that make the program could connect with database are placed.


__init__.py
===========

database.py
===========

queries.py
==========

service.py
==========